PointerDetail class

Constructors

PointerDetail({required int? id, required double x, required double y})

Properties

endPoint Point<double>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
final
movedDistance double
no setter
props List<int>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPoint Point<double>?
getter/setter pair
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
updatePoint Point<double>?
getter/setter pair

Methods

endPointer(double x, double y) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updatePointer(double x, double y) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited